==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/KubernetesRoleStorageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Kubernetes role storage resource
 * @property endpoints Mount points of shares in role(s).
 */
public data class KubernetesRoleStorageArgs(
    public val endpoints: Output<List<MountPointMapArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs =
        com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs.builder()
            .endpoints(
                endpoints?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [KubernetesRoleStorageArgs].
 */
@PulumiTagMarker
public class KubernetesRoleStorageArgsBuilder internal constructor() {
    private var endpoints: Output<List<MountPointMapArgs>>? = null

    /**
     * @param value Mount points of shares in role(s).
     */
    @JvmName("fifolcphhgmnnend")
    public suspend fun endpoints(`value`: Output<List<MountPointMapArgs>>) {
        this.endpoints = value
    }

    @JvmName("gyunjpkwlbdacouc")
    public suspend fun endpoints(vararg values: Output<MountPointMapArgs>) {
        this.endpoints = Output.all(values.asList())
    }

    /**
     * @param values Mount points of shares in role(s).
     */
    @JvmName("rykennxrqxebqhrc")
    public suspend fun endpoints(values: List<Output<MountPointMapArgs>>) {
        this.endpoints = Output.all(values)
    }

    /**
     * @param value Mount points of shares in role(s).
     */
    @JvmName("pflhqammbxbiooov")
    public suspend fun endpoints(`value`: List<MountPointMapArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endpoints = mapped
    }

    /**
     * @param argument Mount points of shares in role(s).
     */
    @JvmName("nclxsdtwgwvkjidq")
    public suspend fun endpoints(argument: List<suspend MountPointMapArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MountPointMapArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.endpoints = mapped
    }

    /**
     * @param argument Mount points of shares in role(s).
     */
    @JvmName("yqttpxhvgmbqqfrd")
    public suspend fun endpoints(vararg argument: suspend MountPointMapArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MountPointMapArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.endpoints = mapped
    }

    /**
     * @param argument Mount points of shares in role(s).
     */
    @JvmName("whcupwamahkgnppr")
    public suspend fun endpoints(argument: suspend MountPointMapArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MountPointMapArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.endpoints = mapped
    }

    /**
     * @param values Mount points of shares in role(s).
     */
    @JvmName("cypdchbucaiurxpy")
    public suspend fun endpoints(vararg values: MountPointMapArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoints = mapped
    }

    internal fun build(): KubernetesRoleStorageArgs = KubernetesRoleStorageArgs(
        endpoints = endpoints,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/KubernetesRoleStorageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Kubernetes role storage resource
 * @property endpoints Mount points of shares in role(s).
 */
public data class KubernetesRoleStorageArgs(
    public val endpoints: Output<List<MountPointMapArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs =
        com.pulumi.azurenative.databoxedge.inputs.KubernetesRoleStorageArgs.builder()
            .endpoints(
                endpoints?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [KubernetesRoleStorageArgs].
 */
@PulumiTagMarker
public class KubernetesRoleStorageArgsBuilder internal constructor() {
    private var endpoints: Output<List<MountPointMapArgs>>? = null

    /**
     * @param value Mount points of shares in role(s).
     */
    @JvmName("hlmytnhsbgqtserp")
    public suspend fun endpoints(`value`: Output<List<MountPointMapArgs>>) {
        this.endpoints = value
    }

    @JvmName("vhwxpyxlesibddif")
    public suspend fun endpoints(vararg values: Output<MountPointMapArgs>) {
        this.endpoints = Output.all(values.asList())
    }

    /**
     * @param values Mount points of shares in role(s).
     */
    @JvmName("teuavxodsubxdsjw")
    public suspend fun endpoints(values: List<Output<MountPointMapArgs>>) {
        this.endpoints = Output.all(values)
    }

    /**
     * @param value Mount points of shares in role(s).
     */
    @JvmName("vqqudaeqkjajhibi")
    public suspend fun endpoints(`value`: List<MountPointMapArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endpoints = mapped
    }

    /**
     * @param argument Mount points of shares in role(s).
     */
    @JvmName("mgoetpdsuwaskcbr")
    public suspend fun endpoints(argument: List<suspend MountPointMapArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MountPointMapArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.endpoints = mapped
    }

    /**
     * @param argument Mount points of shares in role(s).
     */
    @JvmName("whsltwnpejhjtygq")
    public suspend fun endpoints(vararg argument: suspend MountPointMapArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MountPointMapArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.endpoints = mapped
    }

    /**
     * @param argument Mount points of shares in role(s).
     */
    @JvmName("usjugrevvgaqtwhy")
    public suspend fun endpoints(argument: suspend MountPointMapArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MountPointMapArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.endpoints = mapped
    }

    /**
     * @param values Mount points of shares in role(s).
     */
    @JvmName("eibxuxmgckducsre")
    public suspend fun endpoints(vararg values: MountPointMapArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoints = mapped
    }

    internal fun build(): KubernetesRoleStorageArgs = KubernetesRoleStorageArgs(
        endpoints = endpoints,
    )
}
